package com.qmth.teachcloud.eds.dao;


import com.qmth.teachcloud.eds.entity.*;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface GdpuMapper {

    void deleteJwxtJgdmb();
    void deleteJwxtJyzr();
    void deleteJwxtJzgxxb();
    void deleteJwxtKcdmb();
    void deleteZtXsxx();

    void insertJwxtJgdmb(List<JwxtJgdmb> list);
    void insertJwxtJyzr(List<JwxtJyzr> list);
    void insertJwxtJzgxxb(List<JwxtJzgxxb> list);
    void insertJwxtKcdmb(List<JwxtKcdmb> list);
    void insertZtXsxx(List<ZtXsxx> list);
}
